@@ -426,16 +426,16 @@ class OpenSesameIDE(BaseExtension):
         path = editor.file.path
         if not path:
             return
-        mimetype, encoding = mimetypes.guess_type(path)
-        if mimetype in editor.mimetypes:
-            return
-        self.close_tab()
-        self.open_document(path)
         self.extension_manager.fire(
             'ide_save_current_file_as',
             from_path=from_path,
             to_path=path
         )
+        mimetype, encoding = mimetypes.guess_type(path)
+        if mimetype in editor.mimetypes:
+            return
+        self.close_tab()
+        self.open_document(path)
 
     def open_file(self, *args):
 
@@ -451,7 +451,11 @@ class OpenSesameIDE(BaseExtension):
         cfg.file_dialog_path = os.path.dirname(path)
         self.open_document(path)
         # And remember the folder
-        self._add_recent_folder(os.path.dirname(path))
+        folder = os.path.dirname(path)
+        self._open_folder(folder)
+        self._add_recent_folder(folder)
+        self._remember_open_folders()
+        return path
 
     def folder_browsers_visible(self):
 
@@ -736,6 +740,9 @@ class OpenSesameIDE(BaseExtension):
                 label = path[strip_first + 1:]
                 data = path
                 haystack.append((label, data, self.open_document))
+        if not haystack:
+            self.open_file()
+            return
         self.extension_manager.fire(
             u'quick_select',
             haystack=haystack,
@@ -753,6 +760,9 @@ class OpenSesameIDE(BaseExtension):
         }
         for path in sorted(norm_paths):
             haystack.append((path, path, self._open_folder))
+        if not haystack:
+            self.select_and_open_folder()
+            return
         self.extension_manager.fire(
             u'quick_select',
             haystack=haystack,
@@ -1099,7 +1109,6 @@ class OpenSesameIDE(BaseExtension):
         
     def _on_extension_changed(self, ext):
         
-        print(ext)
         cfg.opensesame_ide_default_extension = ext
         
     def _on_editor_created(self, editor):
